@@ -645,17 +645,9 @@ class Commit(object):
         if not account:
             raise ValueError("You need to provide an account")
 
-        # temporarily allow both steem and hive symbols until after HF24
-        legacy_symbols = 0
-        a = Account(account, hived_instance=self.hived)
-        if "reward_steem_balance" in a:
-            legacy_symbols = 1
-        if legacy_symbols == 1:
-            assert asset in ["HIVE", "HBD", "STEEM", "SBD"]
-            if asset == "HIVE":
-                asset = "STEEM"
-            if asset == "HBD":
-                asset = "SBD"
+        # Until HF24, STEEM is the core token name
+        assert asset == "SHTO"
+        asset = "STEEM"
 
         if memo and memo[0] == "#":
             from hivebase import memo as Memo
@@ -685,7 +677,6 @@ class Commit(object):
                 "memo": memo,
             }
         )
-        print(op)
         return self.finalizeOp(op, account, "active")
 
     def withdraw_vesting(self, amount, account=None):
@@ -735,7 +726,7 @@ class Commit(object):
             to = account  # powerup on the same account
 
         # temporarily allow both steem and hive symbols until after HF24
-        asset_symbol = "HIVE"
+        asset_symbol = "STEEM"
         a = Account(account, hived_instance=self.hived)
         if "reward_steem_balance" in a:
             asset_symbol = "STEEM"
@@ -1114,7 +1105,7 @@ class Commit(object):
 
         authority = account[permission]
         try:
-            pubkey = PublicKey(foreign)
+            pubkey = PublicKey(foreign, prefix=self.hived.chain_params["prefix"])
             authority["key_auths"].append([str(pubkey), weight])
         except:  # noqa FIXME(sneak)
             try:
