@@ -2,7 +2,7 @@ import hashlib
 import os
 import re
 from binascii import hexlify, unhexlify
-from hive.utils import compat_bytes, compat_chr
+from .utils import compat_bytes, compat_chr
 
 import ecdsa
 
@@ -17,10 +17,11 @@ class PasswordKey(object):
     passphrase only.
     """
 
-    def __init__(self, account, password, role="active"):
+    def __init__(self, account, password, role="active", prefix="STM"):
         self.account = account
         self.role = role
         self.password = password
+        self.prefix = prefix
 
     def get_private(self):
         """Derive private key from the brain key and the current sequence
@@ -28,7 +29,7 @@ class PasswordKey(object):
         """
         a = compat_bytes(self.account + self.role + self.password, "utf8")
         s = hashlib.sha256(a).digest()
-        return PrivateKey(hexlify(s).decode("ascii"))
+        return PrivateKey(hexlify(s).decode("ascii"), prefix=self.prefix)
 
     def get_public(self):
         return self.get_private().pubkey
