@@ -1,19 +1,25 @@
 import hashlib
-import json
 import struct
 import sys
 from binascii import hexlify, unhexlify
-from collections import OrderedDict
 
-from Crypto.Cipher import AES
+try:
+    from Cryptodome.Cipher import AES
+except ImportError:
+    try:
+        from Crypto.Cipher import AES
+    except ImportError:
+        raise ImportError("Missing dependency: pyCryptodome")
 
-from .operations import Memo
 from .base58 import base58encode, base58decode
 from .account import PrivateKey, PublicKey
-from hive.utils import compat_bytes
+from .utils import compat_bytes
 
 default_prefix = "SHARE"
 
+class PubKeyMismatchException(Exception):
+    """Pubkeys do not match expected key"""
+
 
 def get_shared_secret(priv, pub):
     """Derive the share secret between ``priv`` and ``pub``
@@ -31,9 +37,9 @@ def get_shared_secret(priv, pub):
     pub_point = pub.point()
     priv_point = int(repr(priv), 16)
     res = pub_point * priv_point
-    res_hex = "%032x" % res.x()
+    res_hex = '%032x' % res.x()
     # Zero padding
-    res_hex = "0" * (64 - len(res_hex)) + res_hex
+    res_hex = '0' * (64 - len(res_hex)) + res_hex
     return hashlib.sha512(unhexlify(res_hex)).hexdigest()
 
 
@@ -60,18 +66,18 @@ def init_aes(shared_secret, nonce):
 
 
 def _pad(s, BS):
-    numBytes = BS - len(s) % BS
-    return s + numBytes * struct.pack("B", numBytes)
+    numBytes = (BS - len(s) % BS)
+    return s + numBytes * struct.pack('B', numBytes)
 
 
 def _unpad(s, BS):
-    count = int(struct.unpack("B", compat_bytes(s[-1], "ascii"))[0])
-    if compat_bytes(s[-count::], "ascii") == count * struct.pack("B", count):
+    count = int(struct.unpack('B', bytes(s[-1], 'ascii'))[0])
+    if bytes(s[-count::], 'ascii') == count * struct.pack('B', count):
         return s[:-count]
     return s
 
 
-def encode_memo(priv, pub, nonce, message, **kwargs):
+def encode_memo(priv, pub, nonce, message, prefix="STM", **kwargs):
     """Encode a message with a shared secret between Alice and Bob
 
     :param PrivateKey priv: Private Key (of Alice)
@@ -82,12 +88,11 @@ def encode_memo(priv, pub, nonce, message, **kwargs):
     :rtype: hex
 
     """
-    from hivebase import transactions
+    from .operations import Memo
 
     shared_secret = get_shared_secret(priv, pub)
     aes, check = init_aes(shared_secret, nonce)
-    raw = compat_bytes(message, "utf8")
-
+    raw = bytes(message, 'utf8')
     " Padding "
     BS = 16
     if len(raw) % BS:
@@ -95,28 +100,27 @@ def encode_memo(priv, pub, nonce, message, **kwargs):
     " Encryption "
     cipher = hexlify(aes.encrypt(raw)).decode("ascii")
     prefix = kwargs.pop("prefix", default_prefix)
-    s = OrderedDict(
-        [
-            ("from", format(priv.pubkey, prefix)),
-            ("to", format(pub, prefix)),
-            ("nonce", nonce),
-            ("check", check),
-            ("encrypted", cipher),
-            ("from_priv", repr(priv)),
-            ("to_pub", repr(pub)),
-            ("shared_secret", shared_secret),
-        ]
-    )
-    tx = Memo(**s)
-
-    return "#" + base58encode(hexlify(compat_bytes(tx)).decode("ascii"))
+    s = {
+        "from": format(priv.pubkey, prefix),
+        "to": format(pub, prefix),
+        "nonce": nonce,
+        "check": check,
+        "encrypted": cipher,
+        "from_priv": repr(priv),
+        "to_pub": repr(pub),
+        "shared_secret": shared_secret,
+    }
+    tx = Memo(**s, prefix=prefix)
+    return "#" + base58encode(hexlify(bytes(tx)).decode("ascii"))
 
 
-def decode_memo(priv, message):
+def decode_memo(priv, message, prefix="STM", pubkey=None, **kwargs):
     """Decode a message with a shared secret between Alice and Bob
 
     :param PrivateKey priv: Private Key (of Bob)
     :param base58encoded message: Encrypted Memo message
+    :param str prefix: Used prefix for pubkey presentation
+    :param PublicKey pubkey: (Optional) pubkey to validate message against
     :return: Decrypted message
     :rtype: str
     :raise ValueError: if message cannot be decoded as valid UTF-8
@@ -125,9 +129,9 @@ def decode_memo(priv, message):
     """
     " decode structure "
     raw = base58decode(message[1:])
-    from_key = PublicKey(raw[:66])
+    from_key = PublicKey(raw[:66], prefix=prefix)
     raw = raw[66:]
-    to_key = PublicKey(raw[:66])
+    to_key = PublicKey(raw[:66], prefix=prefix)
     raw = raw[66:]
     nonce = str(struct.unpack_from("<Q", unhexlify(raw[:16]))[0])
     raw = raw[16:]
@@ -142,6 +146,10 @@ def decode_memo(priv, message):
     else:
         raise ValueError("Incorrect PrivateKey")
 
+    if pubkey and get_shared_secret(priv, pubkey) != shared_secret:
+        raise PubKeyMismatchException("Pubkeys do not match expected key")
+
+
     " Init encryption "
     aes, checksum = init_aes(shared_secret, nonce)
 
@@ -151,10 +159,10 @@ def decode_memo(priv, message):
     " Encryption "
     # remove the varint prefix (FIXME, long messages!)
     message = cipher[2:]
-    message = aes.decrypt(unhexlify(compat_bytes(message, "ascii")))
+    message = aes.decrypt(unhexlify(bytes(message, 'ascii')))
     try:
-        return _unpad(message.decode("utf8"), 16)
-    except:  # noqa FIXME(sneak)
+        return _unpad(message.decode('utf8'), 16)
+    except:
         raise ValueError(message)
 
 
