@@ -5,7 +5,7 @@ import re
 import struct
 from collections import OrderedDict
 
-from hive.utils import compat_bytes
+from .utils import compat_bytes
 from .account import PublicKey
 from .operationids import operations
 from .types import (
